@@ -220,7 +220,7 @@ class WrappedAnswer(JsonableAnswer):
         attribute_key_to_type = {"done": bool}
         if type_ not in (None, type[None]):
             attribute_key_to_type["result"] = type_or_annotated
-        new_type_name = prepare_class_name(([type_or_annotated] if notes else []) + [type_],  "Wrapped")
+        new_type_name = prepare_class_name([type_or_annotated],  "Wrapped")
         return create_dataclass(new_type_name, [], attribute_key_to_type)
 
     def __class_getitem__(cls, modifier: Union[HttpStatusCode, ContentType, type, UnionType, type[None]]) -> type:
